==> nudge_leaderboard_ui-0.0.1.tar.gz: lib/features/leaderboard/data/models/get_nudge_leaderboard.dart <==
// To parse this JSON data, do
//
//     final getLeaderboardOnRewards = getLeaderboardOnRewardsFromJson(jsonString);

import 'dart:convert';

import 'package:dio/dio.dart' as dio;

GetNudgeLeaderboard getLeaderboardOnRewardsFromJson(String str) =>
    GetNudgeLeaderboard.fromJson(json.decode(str));

String getLeaderboardOnRewardsToJson(GetNudgeLeaderboard data) =>
    json.encode(data.toJson());

class GetNudgeLeaderboard {
  String status;
  Data data;

  GetNudgeLeaderboard({
    required this.status,
    required this.data,
  });

  factory GetNudgeLeaderboard.fromJson(Map<String, dynamic> json) =>
      GetNudgeLeaderboard(
        status: json["status"],
        data: Data.fromJson(json["data"]),
      );

  Map<String, dynamic> toJson() => {
        "status": status,
        "data": data.toJson(),
      };
}

Future<GetNudgeLeaderboard> getnudgeleaderboard(
  String? authToken,
  String apiUrl,
) async {
  var headers = {'authorization': authToken};
  var request = dio.Dio();
  var response = await request.request(
    apiUrl,
    options: dio.Options(
      method: 'GET',
      headers: headers,
    ),
  );

  if (response.statusCode == 200) {
    if (response.data != null && response.data is Map<String, dynamic>) {
      return GetNudgeLeaderboard.fromJson(response.data);
    } else {
      // Handle the case where response.data is null or not a valid JSON object.
      throw Exception('Invalid JSON data received');
    }
  } else {
    throw Exception('Failed to fetch leaderboard data');
  }
}

class Data {
  User user;
  int rank;
  List<User> users;

  Data({
    required this.user,
    required this.rank,
    required this.users,
  });

  factory Data.fromJson(Map<String, dynamic> json) => Data(
        user: User.fromJson(json["user"]),
        rank: json["rank"],
        users: List<User>.from(json["users"].map((x) => User.fromJson(x))),
      );

  Map<String, dynamic> toJson() => {
        "user": user.toJson(),
        "rank": rank,
        "users": List<dynamic>.from(users.map((x) => x.toJson())),
      };
}

class User {
  String id;
  UserId userId;
  String? rewardId;
  String? compositeId;
  int score;
  DateTime createdAt;
  DateTime updatedAt;
  int v;

  User({
    required this.id,
    required this.userId,
    this.rewardId,
    this.compositeId,
    required this.score,
    required this.createdAt,
    required this.updatedAt,
    required this.v,
  });

  factory User.fromJson(Map<String, dynamic> json) => User(
        id: json["_id"],
        userId: UserId.fromJson(json["userId"]),
        rewardId: json["rewardId"],
        compositeId: json["compositeId"],
        score: json["score"],
        createdAt: DateTime.parse(json["createdAt"]),
        updatedAt: DateTime.parse(json["updatedAt"]),
        v: json["__v"],
      );

  Map<String, dynamic> toJson() => {
        "_id": id,
        "userId": userId.toJson(),
        "rewardId": rewardId,
        "compositeId": compositeId,
        "score": score,
        "createdAt": createdAt.toIso8601String(),
        "updatedAt": updatedAt.toIso8601String(),
        "__v": v,
      };
}

class UserId {
  String id;
  String name;
  String email;
  String externalId;

  UserId({
    required this.id,
    required this.name,
    required this.email,
    required this.externalId,
  });

  factory UserId.fromJson(Map<String, dynamic> json) => UserId(
        id: json["_id"],
        name: json["name"],
        email: json["email"],
        externalId: json["externalId"],
      );

  Map<String, dynamic> toJson() => {
        "_id": id,
        "name": name,
        "email": email,
        "externalId": externalId,
      };
}

==> nudge_leaderboard_ui-0.0.5.tar.gz: lib/features/leaderboard/data/models/get_nudge_leaderboard.dart <==
// To parse this JSON data, do
//
//     final getLeaderboardOnRewards = getLeaderboardOnRewardsFromJson(jsonString);

import 'dart:convert';
import 'package:dio/dio.dart' as dio;

GetNudgeLeaderboard getLeaderboardOnRewardsFromJson(String str) =>
    GetNudgeLeaderboard.fromJson(json.decode(str));

String getLeaderboardOnRewardsToJson(GetNudgeLeaderboard data) =>
    json.encode(data.toJson());

class GetNudgeLeaderboard {
  String status;
  Data data;

  GetNudgeLeaderboard({
    required this.status,
    required this.data,
  });

  factory GetNudgeLeaderboard.fromJson(Map<String, dynamic> json) =>
      GetNudgeLeaderboard(
        status: json["status"],
        data: Data.fromJson(json["data"]),
      );

  Map<String, dynamic> toJson() => {
        "status": status,
        "data": data.toJson(),
      };
}

Future<GetNudgeLeaderboard> getnudgeleaderboard(
  String? authToken,
  String apiUrl,
) async {
  var headers = {'authorization': authToken};
  var request = dio.Dio();
  var response = await request.request(
    apiUrl,
    options: dio.Options(
      method: 'GET',
      headers: headers,
    ),
  );

  if (response.statusCode == 200) {
    if (response.data != null && response.data is Map<String, dynamic>) {
      print('object');
      print(response.data);
      return GetNudgeLeaderboard.fromJson(response.data);
    } else {
      // Handle the case where response.data is null or not a valid JSON object.
      throw Exception('Invalid JSON data received');
    }
  } else {
    throw Exception('Failed to fetch leaderboard data');
  }
}

class Data {
  User user;
  int rank;
  List<User> users;

  Data({
    required this.user,
    required this.rank,
    required this.users,
  });

  factory Data.fromJson(Map<String, dynamic> json) => Data(
        user: User.fromJson(json["user"]),
        rank: json["rank"],
        users: List<User>.from(json["users"].map((x) => User.fromJson(x))),
      );

  Map<String, dynamic> toJson() => {
        "user": user.toJson(),
        "rank": rank,
        "users": List<dynamic>.from(users.map((x) => x.toJson())),
      };
}

class User {
  String id;
  UserId? userId;
  String? rewardId;
  String? compositeId;
  int score;
  DateTime createdAt;
  DateTime updatedAt;
  int v;

  User({
    required this.id,
    this.userId,
    this.rewardId,
    this.compositeId,
    required this.score,
    required this.createdAt,
    required this.updatedAt,
    required this.v,
  });

  factory User.fromJson(Map<String, dynamic> json) => User(
        id: json["_id"],
        userId: json["userId"] == null ? null : UserId.fromJson(json["userId"]),
        rewardId: json["rewardId"],
        compositeId: json["compositeId"],
        score: json["score"],
        createdAt: DateTime.parse(json["createdAt"]),
        updatedAt: DateTime.parse(json["updatedAt"]),
        v: json["__v"],
      );

  Map<String, dynamic> toJson() => {
        "_id": id,
        "userId": userId?.toJson(),
        "rewardId": rewardId,
        "compositeId": compositeId,
        "score": score,
        "createdAt": createdAt.toIso8601String(),
        "updatedAt": updatedAt.toIso8601String(),
        "__v": v,
      };
}

class UserId {
  String id;
  String? name;
  String? email;
  String externalId;
  String? photoUrl;

  UserId({
    required this.id,
    this.name,
    this.email,
    required this.externalId,
    this.photoUrl,
  });

  factory UserId.fromJson(Map<String, dynamic> json) => UserId(
        id: json["_id"],
        name: json["name"],
        email: json["email"],
        externalId: json["externalId"],
        photoUrl: json["photoUrl"],
      );

  Map<String, dynamic> toJson() => {
        "_id": id,
        "name": name,
        "email": email,
        "externalId": externalId,
        "photoUrl": photoUrl,
      };
}
